Welcome to MQT Bench's documentation!
=====================================

MQT Bench is a tool for benchmarking quantum software tools developed as part of the `Munich Quantum Toolkit <https://mqt.readthedocs.io>`_ (*MQT*) by the `Chair for Design Automation <https://www.cda.cit.tum.de/>`_ at the `Technical University of Munich <https://www.tum.de>`_.

We recommend you to start with the :doc:`quickstart guide <Quickstart>`.
If you are interested in the theory behind MQT Bench, have a look at the publication :cite:labelpar:`quetschlich2023mqtbench`.
Furthermore, MQT Bench is also available as a `PennyLane dataset <https://pennylane.ai/datasets/other/mqt-bench>`_.

We appreciate any feedback and contributions to the project. If you want to contribute, you can find more information in the :doc:`Contribution <Contributing>` guide. If you are having trouble with the installation or the usage of MQT Bench, please let us know at our :doc:`Support <Support>` page.

----

 .. toctree::
    :hidden:

    self

 .. toctree::
    :maxdepth: 1
    :caption: User Guide
    :glob:

    Quickstart
    Usage
    Abstraction_levels
    Parameter
    Benchmark_selection
    References

 .. toctree::
    :maxdepth: 1
    :caption: Developers
    :glob:

    Contributing
    DevelopmentGuide
    Support
